@@ -47,5 +47,7 @@ around http_request => sub {
 
 with qw/WWW::JSON::Role::Authentication::Basic
   WWW::JSON::Role::Authentication::OAuth1
-  WWW::JSON::Role::Authentication::OAuth2/;
+  WWW::JSON::Role::Authentication::OAuth2
+  WWW::JSON::Role::Authentication::Header
+  /;
 1;
